#
# spec file for package ocaml-findlib
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010-2011 Andrew Psaltis <ampsaltis at gmail dot com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ocaml-findlib
Version:        1.7.3
Release:        lp151.2.4
%{?ocaml_preserve_bytecode}
Summary:        Objective CAML package manager and build helper
License:        MIT
Group:          Development/Languages/OCaml

Url:            http://projects.camlcity.org/projects/findlib.html
Source0:        findlib-%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#
Recommends:     ocaml-findlib-camlp4
#
Requires:       ocaml-compiler-libs
Requires:       ocaml-runtime
#
Provides:       ocamlfind = %{version}

BuildRequires:  gawk
BuildRequires:  m4
BuildRequires:  ncurses-devel
BuildRequires:  ocaml >= 4.02.0
BuildRequires:  ocaml-camlp4-devel >= 4.02.0
BuildRequires:  ocaml-ocamlbuild
BuildRequires:  ocaml-ocamldoc
BuildRequires:  ocaml-rpm-macros >= 4.02.1

%description
Findlib is a library manager for Objective Caml. It provides a
convention how to store libraries, and a file format ("META") to
describe the properties of libraries. There is also a tool (ocamlfind)
for interpreting the META files, so that it is very easy to use
libraries in programs and scripts.


%package        devel
Summary:        Development files for ocaml-findlib
Group:          Development/Languages/OCaml
Requires:       %{name} = %{version}

%description    devel
The ocaml-findlib-devel package contains libraries and signature files
for developing applications that use ocaml-findlib.



%package camlp4
Summary:        Development files for ocaml-findlib
Group:          Development/Languages/OCaml
Requires:       ocaml-camlp4-devel

%description camlp4
The ocaml-findlib-camlp4 contains signature files for developing applications that use camlp4

%prep
%setup -q -n findlib-%{version}

%build
(cd tools/extract_args && make)
tools/extract_args/extract_args -o src/findlib/ocaml_args.ml ocamlc ocamlcp ocamlmktop ocamlopt ocamldep ocamldoc ||:
./configure -config %{_sysconfdir}/ocamlfind.conf \
  -bindir %{_bindir} \
  -sitelib `ocamlc -where` \
  -mandir %{_mandir} \
  -with-toolbox
make all
%if 0%{?ocaml_native_compiler}
make opt
%endif
rm doc/guide-html/TIMESTAMP

%install
make install prefix=$RPM_BUILD_ROOT
rm -rfv $RPM_BUILD_ROOT%{_libdir}/ocaml/ocamlbuild

%files
%defattr(-,root,root,-)
%doc LICENSE doc/README
%config(noreplace) %{_sysconfdir}/ocamlfind.conf
%{_bindir}/*
%{_mandir}/man?/*
#
%dir %{_libdir}/ocaml
%dir %{_libdir}/ocaml/*
%{_libdir}/ocaml/*/META
#
%exclude %dir %{_libdir}/ocaml/camlp4
%exclude %dir %{_libdir}/ocaml/findlib
%exclude %dir %{_libdir}/ocaml/num-top
%exclude %{_libdir}/ocaml/camlp4/META
%exclude %{_libdir}/ocaml/findlib/META
%exclude %{_libdir}/ocaml/num-top/META
%{_libdir}/ocaml/topfind
%dir %{_libdir}/ocaml/findlib
%if 0%{?ocaml_native_compiler}
%{_libdir}/ocaml/*/*.cmxs
%endif

%files devel
%defattr(-,root,root,-)
%doc LICENSE doc/README doc/guide-html
%{_libdir}/ocaml/*/Makefile.config
#
%dir %{_libdir}/ocaml
%dir %{_libdir}/ocaml/findlib
%dir %{_libdir}/ocaml/num-top
%{_libdir}/ocaml/findlib/META
%{_libdir}/ocaml/num-top/META
%if 0%{?ocaml_native_compiler}
%{_libdir}/ocaml/*/*.a
%{_libdir}/ocaml/*/*.cmxa
%endif
%{_libdir}/ocaml/*/*.cma
%{_libdir}/ocaml/*/*.cmi
%{_libdir}/ocaml/*/*.mli

%files camlp4
%defattr(-,root,root,-)
%dir %{_libdir}/ocaml
%dir %{_libdir}/ocaml/camlp4
%{_libdir}/ocaml/camlp4/META

%changelog
* Tue Jul 25 2017 ohering@suse.de
- Use Group: Development/Languages/OCaml
* Mon Jul 17 2017 ohering@suse.de
- Update to upstream version 1.7.3
  Fix regarding num-top: this library is now also  optional, as num.
  Trying to protect against failures when  several package installs are done in parallel.
  New subpackage "findlib.top" for the toploop
  The "num" library is now optional.
  New command "ocamlfind printppx" that outputs how the ppx preprocessor would be called
  Support for the raw_spacetime library that comes with OCaml 4.04
  Require that ocamlc and ocamlc.opt are installed to the same directory
  "ocamlfind printconf" respects the  environment variable OCAMLFIND_CONF
  Build with -opaque
  Preliminary support for native toplevel
  New options: ocamlfind query -qe -qo
- drop findlib-1.3.3.patch
* Mon Jul 17 2017 ohering@suse.de
- Wrap specfile conditionals to fix quilt setup
* Mon Jul 17 2017 ohering@suse.de
- Remove autodeps for pre openSUSE 12.1 releases
* Wed May 18 2016 ohering@suse.de
-  Update to upstream version 1.6.2 (fate#320836)
  Adding an "ocamldoc" library, providing the cmi's for ocamldoc plugins
  Support for OCaml-4.03: recognize that the new -color option has an argument
  Adding support for dynamically loading  packages
  new "plugin" variable, new  Fl_dynload module.
  New command "ocamlfind lint" for checking META files
  Allow to query the location of the META file of a package:
  "ocamlfind query -format '%%m'"
  Get the install path for the META file of packages:
  "ocamlfind printconf metapath"
  The switch -only-show did not work as described.
* Tue Nov 10 2015 ohering@suse.de
- Add hardcoded Provides for pre 12.1 repos
* Thu Oct 23 2014 ohering@suse.de
-  Update to upstream version 1.5.5
  New ppxopt META variables.
  Support for OCAMLFIND_TOOLCHAIN environment variable.
* Thu Oct 23 2014 ohering@suse.de
- BuildRequire ocaml-rpm-macros
* Fri Oct 10 2014 ohering@suse.de
- BuildRequire at least ocaml 4.02
* Wed Oct  8 2014 ohering@suse.de
-  Update to upstream version 1.5.3
  The installation of "bytes" respects now $prefix and the
  configured destination.
  New option -pp for "ocamlfind query", to get preprocessor
  packages.  Updated the compatibility Bytes module to support
  extend, init, mapi,  blit_string.
-  1.5.2: support for the query formats "%%+a" and "%%+A".
  Fix: the "ppx" property is now also path-expanded when
  interpreted in a toploop.
  Fix: implicit "ppx" is not path-expanded anymore.
  Fix: Build bytes.cmxs only if natdynlink is enabled.
-  1.5.1: includes a file that was missing in 1.5
-  1.5: Including the "bytes" package that is either a compat
  package for ocaml < 4.02 or a fake package for ocaml >= 4.02.
  The package aims at helping to support the transition to the new
  "bytes" type for mutable strings.
  Also installing findlib.cmxs if OCaml supports it.
  Allowing to disable camlp4 (in prep for OCaml-4.02).
  The "ppx" package property can be specified for constructing
  ppx-type preprocessor.
-  1.4.1:ocamldoc: The order of -ppopt arguments was changed by
  ocamlfind, which is not correct.
-  1.4: Fixed performance bug when many arguments need to be processed.
  Auto-configuring ocamldoc.opt if it is found.
  New config switch -no-custom to prevent that "ocamlfind" is
  linked in custom-runtime mode (bytecode only).
  The library dbm is no longer part of OCaml, and now optional in
  findlib
  Support for ocamloptp.
  New function Topfind.log for controlling the verbosity.
  Rewritten Fl_metascanner without camlp4
* Mon Jun  3 2013 ohering@suse.de
- Recompress with xz
* Fri Mar  8 2013 ohering@suse.de
- remove ExclusiveArch, its a generic package which depends on ocaml
* Thu Feb 21 2013 ohering@suse.de
- package compiler-libs/
* Wed Jan 16 2013 ohering@suse.de
- disable also /usr/lib/rpm/find-debuginfo.sh
* Mon Jan 14 2013 ohering@suse.de
- disable strip, it destroys bytecode binaries
* Mon Jan 14 2013 ohering@suse.de
- change Requires: version-release to just Requires: version
* Fri Nov 23 2012 ohering@suse.de
- restore BuildRequire ocaml-camlp4-devel because the solver
  triggers only on package names
* Tue Nov 13 2012 ohering@suse.de
- add DESTDIR support
* Tue Sep 18 2012 ohering@suse.de
- BuildRequire just camlp4 to allow build within sles11 [fate#312159]
* Sun Sep 16 2012 ohering@suse.de
-  Update to upstream version 1.3.3
-  1.3.3: OCaml-4: using the new #remove_directory directive  if present.
  Better compatibility with the OCaml version from Homebrew.
-  1.3.2: Handling of empty arguments (Wojciech Meyer).
  Added entry for camlp4.fulllib.
  New switch -add for "ocamlfind install" (Hans Ole Rafaelsen).
  Further fixes for ocaml-4.00.
  Fixing the recognition of double .cmi interface files.
  Fixing -dontlink (it is now deeply interpreted).
-  1.3.1: Fixing a bug with ocamlmklib that slipped through in 1.3.0
-  1.3.0: Fixes for ocaml-4.00 (especially topfind).
  Emitting an error if the configuration file does not exist.
  Emitting a warning if the selected toolchain does not exist.
  camlp4 is referenced by "+camlp4" in META.
  Including the sources for the documentation in the tarball.
  License change (simplification) for num_top_printers.mli.
  Fix ocamlmklib wrapper: processing contracted args (like -L/dir) correctly.
  Many wrappers get a new option -passrest instructing to pass all remaining
  options on the command-line unchanged to the invoked tool.
  Prettified -help output.
-  1.2.8: Adding support for ocamlmklib (B. Meurer's patches)
  Fix for win32 in the configure script.
* Thu Sep 15 2011 ampsaltis@gmail.com
- Remove some unneeded commands in the build section
* Fri Jul 22 2011 ampsaltis@gmail.com
- Fix license (sort of, they're the same thing, really)
- Primary package provides ocamlfind
- Fixed some rpmlint warnings
* Fri Jun 17 2011 ampsaltis@gmail.com
- Use ocaml-camlp4-devel in BuildRequires
* Wed May 18 2011 ampsaltis@gmail.com
- Add this file.
- New upstream version 1.2.7
- Fix: if a META file defines several packages, and one of the packages
  has a broken dependency, ocamlfind used to report all errors even if
  the broken packages were not used. This is now changed - broken
  subpackages are ignored when they are not needed, in the same way as
  broken top-level packages are ignored when not needed. (Thanks to
  Sylvain Le Gall for reporting the problem.)
- Added -thread and -vmthread switches to "ocamlfind ocamldoc".
  These actually only add the right predicates. (Thanks to Vladimir
  Ivanov for pointing this problem out.)
- Package warnings can be emitted by "ocamlfind ocamldoc".
* Wed Apr 20 2011 ampsaltis@gmail.com
- Use internal dependency generator
